@@ -6,16 +6,23 @@ def get_rendered_source_filepath(filepath):
     filename = os.path.basename(filepath)
     return os.path.join(dirname, '.rendered.' + filename)
 
+class BuildArgs(dict):
+    _key_mapping = {
+        'compiler_args': 'extra_compile_args',
+        'linker_args': 'extra_link_args',
+    }
+
+    def __getitem__(self, key):
+        return super(BuildArgs, self).__getitem__(self._key_mapping.get(key, key))
+
+    def __setitem__(self, key, value):
+        super(BuildArgs, self).__setitem__(self._key_mapping.get(key, key), value)
+
 def setup_pybind11(cfg):
     import pybind11
-    cfg['include_dirs'] = (
-        cfg.get('include_dirs', []) +
-        [pybind11.get_include(), pybind11.get_include(True)]
-    )
-    cfg['compiler_args'] = (
-        cfg.get('compiler_args', []) +
-        ['-std=c++11']
-    )
+    cfg['include_dirs'] += [pybind11.get_include(), pybind11.get_include(True)]
+    # Prefix with c++11 arg instead of suffix so that if a user specifies c++14 (or later!) then it won't be overridden.
+    cfg['compiler_args'] = ['-std=c++11', '-fvisibility=hidden'] + cfg['compiler_args']
 
 def run_templating(module_data):
     import mako.template
@@ -28,7 +35,16 @@ def run_templating(module_data):
     else:
         import io
 
-    module_data['cfg'] = dict()
+    module_data['cfg'] = BuildArgs(
+        sources = [],
+        include_dirs = [],
+        extra_compile_args = [],
+        libraries = [],
+        library_dirs = [],
+        extra_link_args = [],
+        dependencies = [],
+        parallel = False,
+    )
     module_data['setup_pybind11'] = setup_pybind11
     buf = io.StringIO()
     ctx = mako.runtime.Context(buf, **module_data)
